@@ -2,7 +2,7 @@
  * input_programs.c: es_descriptor_t, pgrm_descriptor_t management
  *****************************************************************************
  * Copyright (C) 1999, 2000 VideoLAN
- * $Id: input_programs.c,v 1.31 2001/02/08 17:44:12 massiot Exp $
+ * $Id: input_programs.c,v 1.39 2001/03/02 15:51:22 massiot Exp $
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *
@@ -87,6 +87,11 @@ void input_EndStream( input_thread_t * p_input )
     {
         input_DelES( p_input, p_input->stream.pp_es[0] );
     }
+
+    if( p_input->stream.p_demux_data != NULL )
+    {
+        free( p_input->stream.p_demux_data );
+    }
 }
 
 /*****************************************************************************
@@ -226,6 +231,91 @@ void input_DelProgram( input_thread_t * p_input, pgrm_descriptor_t * p_pgrm )
     free( p_pgrm );
 }
 
+/*****************************************************************************
+ * input_AddArea: add and init an area descriptor
+ *****************************************************************************
+ * This area descriptor will be referenced in the given stream descriptor
+ *****************************************************************************/
+input_area_t * input_AddArea( input_thread_t * p_input )
+{
+    /* Where to add the pgrm */
+    int i_area_index = p_input->stream.i_area_nb;
+
+    intf_DbgMsg("Adding description for area %d", i_area_index );
+
+    /* Add an entry to the list of program associated with the stream */
+    p_input->stream.i_area_nb++;
+    p_input->stream.pp_areas = realloc( p_input->stream.pp_areas,
+                                        p_input->stream.i_area_nb
+                                            * sizeof(input_area_t *) );
+    if( p_input->stream.pp_areas == NULL )
+    {
+        intf_ErrMsg( "Unable to realloc memory in input_AddArea" );
+        return( NULL );
+    }
+    
+    /* Allocate the structure to store this description */
+    p_input->stream.pp_areas[i_area_index] =
+                                        malloc( sizeof(input_area_t) );
+    if( p_input->stream.pp_areas[i_area_index] == NULL )
+    {
+        intf_ErrMsg( "Unable to allocate memory in input_AddArea" );
+        return( NULL );
+    }
+    
+    /* Init this entry */
+    p_input->stream.pp_areas[i_area_index]->i_id = 0;
+    p_input->stream.pp_areas[i_area_index]->i_start = 0;
+    p_input->stream.pp_areas[i_area_index]->i_size = 0;
+    p_input->stream.pp_areas[i_area_index]->i_tell = 0;
+    p_input->stream.pp_areas[i_area_index]->i_seek = NO_SEEK;
+    p_input->stream.pp_areas[i_area_index]->i_part_nb = 0;
+    p_input->stream.pp_areas[i_area_index]->i_part= 0;
+
+    return p_input->stream.pp_areas[i_area_index];
+}
+
+/*****************************************************************************
+ * input_DelArea: destroy a area descriptor
+ *****************************************************************************
+ * All ES descriptions referenced in the descriptor will be deleted.
+ *****************************************************************************/
+void input_DelArea( input_thread_t * p_input, input_area_t * p_area )
+{
+    int i_area_index;
+
+    ASSERT( p_area );
+
+    intf_DbgMsg("Deleting description for area %d", p_area->i_id );
+
+    /* Find the area in the areas table */
+    for( i_area_index = 0; i_area_index < p_input->stream.i_area_nb;
+         i_area_index++ )
+    {
+        if( p_input->stream.pp_areas[i_area_index] == p_area )
+            break;
+    }
+
+    /* Remove this area from the stream's list of areas */
+    p_input->stream.i_area_nb--;
+
+    p_input->stream.pp_areas[i_area_index] =
+        p_input->stream.pp_areas[p_input->stream.i_area_nb];
+    p_input->stream.pp_areas = realloc( p_input->stream.pp_areas,
+                                           p_input->stream.i_area_nb
+                                            * sizeof(input_area_t *) );
+
+    if( p_input->stream.i_area_nb && p_input->stream.pp_areas == NULL)
+    {
+        intf_ErrMsg( "input error: unable to realloc area list"
+                     " in input_DelArea" );
+    }
+
+    /* Free the description of this area */
+    free( p_area );
+}
+
+
 /*****************************************************************************
  * input_FindES: returns a pointer to an ES described by its ID
  *****************************************************************************/
@@ -388,41 +478,6 @@ void input_DelES( input_thread_t * p_input, es_descriptor_t * p_es )
     
 }
 
-#ifdef STATS
-/*****************************************************************************
- * input_DumpStream: dumps the contents of a stream descriptor
- *****************************************************************************/
-void input_DumpStream( input_thread_t * p_input )
-{
-    int i, j;
-#define S   p_input->stream
-    intf_Msg( "input info: Dumping stream ID 0x%x", S.i_stream_id );
-    if( S.b_seekable )
-        intf_Msg( "input info: seekable stream, position: %lld/%lld",
-                  S.i_tell, S.i_size );
-    else
-        intf_Msg( "input info: %s", S.b_pace_control ? "pace controlled" :
-                  "pace un-controlled" );
-#undef S
-    for( i = 0; i < p_input->stream.i_pgrm_number; i++ )
-    {
-#define P   p_input->stream.pp_programs[i]
-        intf_Msg( "input info: Dumping program 0x%x, version %d (%s)",
-                  P->i_number, P->i_version,
-                  P->b_is_ok ? "complete" : "partial" );
-#undef P
-        for( j = 0; j < p_input->stream.pp_programs[i]->i_es_number; j++ )
-        {
-#define ES  p_input->stream.pp_programs[i]->pp_es[j]
-            intf_Msg( "input info: ES 0x%x, stream 0x%x, type 0x%x, %s",
-                      ES->i_id, ES->i_stream_id, ES->i_type,
-                      ES->p_decoder_fifo != NULL ? "selected" : "not selected");
-#undef ES
-        }
-    }
-}
-#endif
-
 /*****************************************************************************
  * InitDecConfig: initializes a decoder_config_t
  *****************************************************************************/
@@ -452,6 +507,19 @@ static int InitDecConfig( input_thread_t * p_input, es_descriptor_t * p_es,
 
     p_config->pf_init_bit_stream = InitBitstream;
 
+    p_input->stream.i_selected_es_number++;
+    p_input->stream.pp_selected_es = realloc(
+                                       p_input->stream.pp_selected_es,
+                                       p_input->stream.i_selected_es_number
+                                        * sizeof(es_descriptor_t *) );
+    if( p_input->stream.pp_selected_es == NULL )
+    {
+        intf_ErrMsg( "Unable to realloc memory in input_SelectES" );
+        return(-1);
+    }
+    p_input->stream.pp_selected_es[p_input->stream.i_selected_es_number - 1]
+            = p_es;
+
     return( 0 );
 }
 
@@ -505,6 +573,9 @@ static adec_config_t * GetAdecConfig( input_thread_t * p_input,
 
 /*****************************************************************************
  * input_SelectES: selects an ES and spawns the associated decoder
+ *****************************************************************************
+ * Remember we are still supposed to have stream_lock when entering this
+ * function ?
  *****************************************************************************/
 /* FIXME */
 vlc_thread_t adec_CreateThread( void * );
@@ -516,6 +587,7 @@ int input_SelectES( input_thread_t * p_input, es_descriptor_t * p_es )
 {
     /* FIXME ! */
     decoder_capabilities_t  decoder;
+    void *                  p_config;
 
 #ifdef DEBUG_INPUT
     intf_DbgMsg( "Selecting ES 0x%x", p_es->i_id );
@@ -534,8 +606,13 @@ int input_SelectES( input_thread_t * p_input, es_descriptor_t * p_es )
         if( p_main->b_audio )
         {
             decoder.pf_create_thread = adec_CreateThread;
-            p_es->thread_id = input_RunDecoder( &decoder,
-                                    (void *)GetAdecConfig( p_input, p_es ) );
+            p_config = (void *)GetAdecConfig( p_input, p_es );
+
+            /* Release the lock, not to block the input thread during
+             * the creation of the thread. */
+            vlc_mutex_unlock( &p_input->stream.stream_lock );
+            p_es->thread_id = input_RunDecoder( &decoder, p_config );
+            vlc_mutex_lock( &p_input->stream.stream_lock );
         }
         break;
 
@@ -544,8 +621,13 @@ int input_SelectES( input_thread_t * p_input, es_descriptor_t * p_es )
         if( p_main->b_video )
         {
             decoder.pf_create_thread = vpar_CreateThread;
-            p_es->thread_id = input_RunDecoder( &decoder,
-                                    (void *)GetVdecConfig( p_input, p_es ) );
+            p_config = (void *)GetVdecConfig( p_input, p_es );
+
+            /* Release the lock, not to block the input thread during
+             * the creation of the thread. */
+            vlc_mutex_unlock( &p_input->stream.stream_lock );
+            p_es->thread_id = input_RunDecoder( &decoder, p_config );
+            vlc_mutex_lock( &p_input->stream.stream_lock );
         }
         break;
 
@@ -553,8 +635,13 @@ int input_SelectES( input_thread_t * p_input, es_descriptor_t * p_es )
         if( p_main->b_audio )
         {
             decoder.pf_create_thread = ac3dec_CreateThread;
-            p_es->thread_id = input_RunDecoder( &decoder,
-                                    (void *)GetAdecConfig( p_input, p_es ) );
+            p_config = (void *)GetAdecConfig( p_input, p_es );
+
+            /* Release the lock, not to block the input thread during
+             * the creation of the thread. */
+            vlc_mutex_unlock( &p_input->stream.stream_lock );
+            p_es->thread_id = input_RunDecoder( &decoder, p_config );
+            vlc_mutex_lock( &p_input->stream.stream_lock );
         }
         break;
 
@@ -562,8 +649,13 @@ int input_SelectES( input_thread_t * p_input, es_descriptor_t * p_es )
         if( p_main->b_video )
         {
             decoder.pf_create_thread = spudec_CreateThread;
-            p_es->thread_id = input_RunDecoder( &decoder,
-                                    (void *)GetVdecConfig( p_input, p_es ) );
+            p_config = (void *)GetVdecConfig( p_input, p_es );
+
+            /* Release the lock, not to block the input thread during
+             * the creation of the thread. */
+            vlc_mutex_unlock( &p_input->stream.stream_lock );
+            p_es->thread_id = input_RunDecoder( &decoder, p_config );
+            vlc_mutex_lock( &p_input->stream.stream_lock );
         }
         break;
 
@@ -578,20 +670,54 @@ int input_SelectES( input_thread_t * p_input, es_descriptor_t * p_es )
         return( -1 );
     }
 
-    if( p_es->p_decoder_fifo != NULL )
+    return( 0 );
+}
+
+/*****************************************************************************
+ * input_UnselectES: removes an ES from the list of selected ES
+ *****************************************************************************/
+int input_UnselectES( input_thread_t * p_input, es_descriptor_t * p_es )
+{
+
+    int     i_index = 0;
+
+#ifdef DEBUG_INPUT
+    intf_DbgMsg( "Unselecting ES 0x%x", p_es->i_id );
+#endif
+
+    if( p_es->p_decoder_fifo == NULL )
     {
-        p_input->stream.i_selected_es_number++;
+        intf_ErrMsg( "ES %d is not selected", p_es->i_id );
+        return( -1 );
+    }
+
+    /* Release lock, not to block the input thread. */
+    vlc_mutex_unlock( &p_input->stream.stream_lock );
+    input_EndDecoder( p_input, p_es );
+    vlc_mutex_lock( &p_input->stream.stream_lock );
+
+    if( p_es->p_decoder_fifo == NULL )
+    {
+        p_input->stream.i_selected_es_number--;
+
+        while( ( i_index < p_input->stream.i_selected_es_number ) &&
+               ( p_input->stream.pp_selected_es[i_index] != p_es ) )
+        {
+            i_index++;
+        }
+
+        p_input->stream.pp_selected_es[i_index] = 
+          p_input->stream.pp_selected_es[p_input->stream.i_selected_es_number];
+
         p_input->stream.pp_selected_es = realloc(
                                            p_input->stream.pp_selected_es,
                                            p_input->stream.i_selected_es_number
                                             * sizeof(es_descriptor_t *) );
         if( p_input->stream.pp_selected_es == NULL )
         {
-            intf_ErrMsg( "Unable to realloc memory in input_SelectES" );
+            intf_ErrMsg( "Unable to realloc memory in input_UnSelectES" );
             return(-1);
         }
-        p_input->stream.pp_selected_es[p_input->stream.i_selected_es_number - 1]
-                = p_es;
     }
     return( 0 );
 }
